Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1075)

Unified Diff: chrome/browser/views/find_bar_view.h

Issue 200035: First cut at implementation of FindBar for views / gtk... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/views/find_bar_view.h
===================================================================
--- chrome/browser/views/find_bar_view.h (revision 25765)
+++ chrome/browser/views/find_bar_view.h (working copy)
@@ -11,7 +11,7 @@
#include "views/controls/button/button.h"
#include "views/controls/textfield/textfield.h"
-class FindBarWin;
+class FindBarHost;
namespace views {
class ImageButton;
@@ -24,7 +24,7 @@
//
// The FindInPageView is responsible for drawing the UI controls of the
// FindInPage window, the find text box, the 'Find' button and the 'Close'
// button. It communicates the user search words to the FindBarWin.
//
////////////////////////////////////////////////////////////////////////////////
class FindBarView : public views::View,
@@ -38,7 +38,7 @@
CLOSE_TAG, // The Close button (the 'X').
};
- explicit FindBarView(FindBarWin* container);
+ explicit FindBarView(FindBarHost* container);
virtual ~FindBarView();
// Sets the text displayed in the text box.
@@ -97,7 +97,7 @@
// Manages the OS-specific view for the find bar and acts as an intermediary
// between us and the TabContentsView.
- FindBarWin* container_;
+ FindBarHost* container_;
// The controls in the window.
views::Textfield* find_text_;
@@ -24,7 +24,7 @@
// The FindInPageView is responsible for drawing the UI controls of the
// FindInPage window, the find text box, the 'Find' button and the 'Close'
-// button. It communicates the user search words to the FindBarWin.
+// button. It communicates the user search words to the FindBarHost.
//
////////////////////////////////////////////////////////////////////////////////

Powered by Google App Engine
This is Rietveld 408576698